gdpr_admob_testing library
Testing and advanced-integration interfaces for gdpr_admob.
Most applications only need package:gdpr_admob/gdpr_admob.dart. Import
this library when injecting test doubles into GdprAdmob.withDependencies.
Classes
- AdsGateway
- Boundary between consent policy and a concrete mobile ads SDK.
- ConsentGateway
- Boundary between consent policy and a concrete consent SDK.