AdsGateway class abstract interface

Boundary between consent policy and a concrete mobile ads SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(GdprAdRequestConfiguration? configuration) Future<void>
Applies optional global request settings and initializes Mobile Ads.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited