getPrivacyOptionsRequirementStatus abstract method
Returns whether the host app must expose privacy options.
Implementation
Future<GdprPrivacyOptionsRequirementStatus>
getPrivacyOptionsRequirementStatus();
Returns whether the host app must expose privacy options.
Future<GdprPrivacyOptionsRequirementStatus>
getPrivacyOptionsRequirementStatus();