loadAndShowConsentFormIfRequired abstract method
Loads and presents a consent form only when UMP requires one.
Implementation
Future<void> loadAndShowConsentFormIfRequired();
Loads and presents a consent form only when UMP requires one.
Future<void> loadAndShowConsentFormIfRequired();