GdprDebugSettings class final

Explicit test-only settings for Google UMP.

Constructors

GdprDebugSettings({GdprDebugGeography geography = GdprDebugGeography.disabled, List<String> testDeviceIdentifiers = const <String>[]})
Creates UMP debug settings.
const

Properties

geography GdprDebugGeography
Region to simulate on registered test devices.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testDeviceIdentifiers List<String>
Hashed UMP test-device identifiers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited